@@ -19,8 +19,8 @@ var (
 type TestPaletteRequest struct {
 	Case          string
 	Request       Ansi
-	ExpectedError bool
 	Expected      Ansi
+	ExpectedError bool
 }
 
 func TestPaletteShouldResolveColorFromTestPalette(t *testing.T) {
@@ -203,7 +203,7 @@ func TestPaletteShouldHandleEmptyKey(t *testing.T) {
 }
 
 func BenchmarkPaletteMixedCaseResolution(b *testing.B) {
-	for i := 0; i < b.N; i++ {
+	for b.Loop() {
 		benchmarkPaletteMixedCaseResolution()
 	}
 }
