@@ -68,21 +68,22 @@ type Config struct {
 	Format                  string                 `json:"-" toml:"-" yaml:"-"`
 	TerminalBackground      color.Ansi             `json:"terminal_background,omitempty" toml:"terminal_background,omitempty" yaml:"terminal_background,omitempty"`
 	ToolTipsAction          Action                 `json:"tooltips_action,omitempty" toml:"tooltips_action,omitempty" yaml:"tooltips_action,omitempty"`
-	Tooltips                []*Segment             `json:"tooltips,omitempty" toml:"tooltips,omitempty" yaml:"tooltips,omitempty"`
 	Blocks                  []*Block               `json:"blocks,omitempty" toml:"blocks,omitempty" yaml:"blocks,omitempty"`
-	ITermFeatures           terminal.ITermFeatures `json:"iterm_features,omitempty" toml:"iterm_features,omitempty" yaml:"iterm_features,omitempty"`
 	Cycle                   color.Cycle            `json:"cycle,omitempty" toml:"cycle,omitempty" yaml:"cycle,omitempty"`
-	Version                 int                    `json:"version" toml:"version" yaml:"version"`
-	EnableCursorPositioning bool                   `json:"enable_cursor_positioning,omitempty" toml:"enable_cursor_positioning,omitempty" yaml:"enable_cursor_positioning,omitempty"`
-	ShellIntegration        bool                   `json:"shell_integration,omitempty" toml:"shell_integration,omitempty" yaml:"shell_integration,omitempty"`
-	MigrateGlyphs           bool                   `json:"-" toml:"-" yaml:"-"`
-	Async                   bool                   `json:"async,omitempty" toml:"async,omitempty" yaml:"async,omitempty"`
-	FinalSpace              bool                   `json:"final_space,omitempty" toml:"final_space,omitempty" yaml:"final_space,omitempty"`
-	UpgradeNotice           bool                   `json:"-" toml:"-" yaml:"-"`
+	ITermFeatures           terminal.ITermFeatures `json:"iterm_features,omitempty" toml:"iterm_features,omitempty" yaml:"iterm_features,omitempty"`
+	Tooltips                []*Segment             `json:"tooltips,omitempty" toml:"tooltips,omitempty" yaml:"tooltips,omitempty"`
+	hash                    uint64
+	Version                 int  `json:"version" toml:"version" yaml:"version"`
+	MigrateGlyphs           bool `json:"-" toml:"-" yaml:"-"`
+	Async                   bool `json:"async,omitempty" toml:"async,omitempty" yaml:"async,omitempty"`
+	ShellIntegration        bool `json:"shell_integration,omitempty" toml:"shell_integration,omitempty" yaml:"shell_integration,omitempty"`
+	FinalSpace              bool `json:"final_space,omitempty" toml:"final_space,omitempty" yaml:"final_space,omitempty"`
+	UpgradeNotice           bool `json:"-" toml:"-" yaml:"-"`
 	updated                 bool
 	extended                bool
 	PatchPwshBleed          bool `json:"patch_pwsh_bleed,omitempty" toml:"patch_pwsh_bleed,omitempty" yaml:"patch_pwsh_bleed,omitempty"`
 	AutoUpgrade             bool `json:"-" toml:"-" yaml:"-"`
+	EnableCursorPositioning bool `json:"enable_cursor_positioning,omitempty" toml:"enable_cursor_positioning,omitempty" yaml:"enable_cursor_positioning,omitempty"`
 }
 
 func (cfg *Config) MakeColors(env runtime.Environment) color.String {
@@ -203,15 +204,15 @@ func (cfg *Config) upgradeFeatures() shell.Features {
 	}
 
 	autoUpgrade := cfg.Upgrade.Auto
-	if _, OK := cache.Get[string](cache.Device, AUTOUPGRADE); OK {
-		log.Debug("auto upgrade key found")
-		autoUpgrade = true
+	if val, OK := cache.Get[bool](cache.Device, AUTOUPGRADE); OK {
+		log.Debug("auto upgrade key found, overriding config")
+		autoUpgrade = val
 	}
 
 	upgradeNotice := cfg.Upgrade.DisplayNotice
-	if _, OK := cache.Get[string](cache.Device, UPGRADENOTICE); OK {
-		log.Debug("upgrade notice key found")
-		upgradeNotice = true
+	if val, OK := cache.Get[bool](cache.Device, UPGRADENOTICE); OK {
+		log.Debug("upgrade notice key found, overriding config")
+		upgradeNotice = val
 	}
 
 	if upgradeNotice && !autoUpgrade {
@@ -226,3 +227,7 @@ func (cfg *Config) upgradeFeatures() shell.Features {
 
 	return feats
 }
+
+func (cfg *Config) Hash() uint64 {
+	return cfg.hash
+}
