@@ -5,6 +5,7 @@ import (
 	"fmt"
 	"os"
 	"path/filepath"
+	"strconv"
 	"strings"
 	"testing"
 	"time"
@@ -26,7 +27,7 @@ const (
 func TestEnabledGitNotFound(t *testing.T) {
 	env := new(mock.Environment)
 	env.On("InWSLSharedDrive").Return(false)
-	env.On("HasCommand", "git").Return(false)
+	env.On("HasParentFilePath", ".git", true).Return((*runtime.FileInfo)(nil), errors.New("no .git found (mock)"))
 	env.On("GOOS").Return("")
 	env.On("IsWsl").Return(false)
 
@@ -147,63 +148,45 @@ func TestEnabledInWorktree(t *testing.T) {
 
 func TestEnabledInBareRepo(t *testing.T) {
 	cases := []struct {
-		Case            string
-		HEAD            string
-		IsBare          string
-		Remote          string
-		RemoteURL       string
-		ExpectedHEAD    string
-		ExpectedRemote  string
-		FetchRemote     bool
-		ExpectedEnabled bool
+		Case   string
+		HEAD   string
+		IsBare bool
 	}{
 		{
-			Case:            "Bare repo on main",
-			IsBare:          trueStr,
-			HEAD:            "ref: refs/heads/main",
-			ExpectedEnabled: true,
-			ExpectedHEAD:    "main",
+			Case:   "Bare repo on main",
+			IsBare: true,
+			HEAD:   "ref: refs/heads/main",
 		},
 		{
 			Case:   "Not a bare repo",
-			IsBare: "false",
-		},
-		{
-			Case:            "Bare repo on main remote enabled",
-			IsBare:          trueStr,
-			HEAD:            "ref: refs/heads/main",
-			ExpectedEnabled: true,
-			ExpectedHEAD:    "main",
-			FetchRemote:     true,
-			Remote:          "origin",
-			RemoteURL:       "git@github.com:JanDeDobbeleer/oh-my-posh.git",
-			ExpectedRemote:  "\uf408",
+			HEAD:   "ref: refs/heads/main",
+			IsBare: false,
 		},
 	}
 	for _, tc := range cases {
-		pwd := "/home/user/bare.git"
+		path := "git"
 		env := new(mock.Environment)
 		env.On("InWSLSharedDrive").Return(false)
 		env.On("GOOS").Return("")
 		env.On("HasCommand", "git").Return(true)
-		env.On("HasParentFilePath", ".git", true).Return(&runtime.FileInfo{}, errors.New("nope"))
-		env.MockGitCommand(pwd, tc.IsBare, "rev-parse", "--is-bare-repository")
-		env.On("Pwd").Return(pwd)
-		env.On("FileContent", "/home/user/bare.git/HEAD").Return(tc.HEAD)
-		env.MockGitCommand(pwd, tc.Remote, "remote")
-		env.MockGitCommand(pwd, tc.RemoteURL, "remote", "get-url", tc.Remote)
+
+		configData := fmt.Sprintf(`[core]
+		bare = %s`, strconv.FormatBool(tc.IsBare))
+
+		env.On("HasParentFilePath", ".git", true).Return(&runtime.FileInfo{IsDir: true, Path: path}, nil)
+		env.On("FileContent", "git/config").Return(configData)
+		env.On("FileContent", "git/HEAD").Return(tc.HEAD)
 
 		props := properties.Map{
-			FetchBareInfo:     true,
-			FetchUpstreamIcon: tc.FetchRemote,
+			FetchBareInfo: true,
 		}
 
 		g := &Git{}
 		g.Init(props, env)
 
-		assert.Equal(t, tc.ExpectedEnabled, g.Enabled(), tc.Case)
-		assert.Equal(t, tc.ExpectedHEAD, g.Ref, tc.Case)
-		assert.Equal(t, tc.ExpectedRemote, g.UpstreamIcon, tc.Case)
+		_ = g.Enabled()
+
+		assert.Equal(t, tc.IsBare, g.IsBare, tc.Case)
 	}
 }
 
@@ -217,7 +200,7 @@ func TestGetGitOutputForCommand(t *testing.T) {
 	env.On("GOOS").Return("unix")
 
 	g := &Git{
-		scm: scm{
+		Scm: Scm{
 			command: GITCOMMAND,
 		},
 	}
@@ -372,7 +355,7 @@ func TestSetGitHEADContextClean(t *testing.T) {
 		}
 
 		g := &Git{
-			scm: scm{
+			Scm: Scm{
 				command: GITCOMMAND,
 			},
 			ShortHash: "1234567",
@@ -414,14 +397,14 @@ func TestSetPrettyHEADName(t *testing.T) {
 		}
 
 		g := &Git{
-			scm: scm{
+			Scm: Scm{
 				command: GITCOMMAND,
 			},
 			ShortHash: tc.ShortHash,
 		}
 		g.Init(props, env)
 
-		g.setPrettyHEADName()
+		g.setHEADName()
 		assert.Equal(t, tc.Expected, g.HEAD, tc.Case)
 	}
 }
@@ -581,7 +564,7 @@ func TestSetGitStatus(t *testing.T) {
 		env.MockGitCommand("", strings.ReplaceAll(tc.Output, "\t", ""), "status", "-unormal", "--branch", "--porcelain=2")
 
 		g := &Git{
-			scm: scm{
+			Scm: Scm{
 				command: GITCOMMAND,
 			},
 		}
@@ -628,7 +611,7 @@ func TestGetStashContextZeroEntries(t *testing.T) {
 		env.On("FileContent", "/logs/refs/stash").Return(tc.StashContent)
 
 		g := &Git{
-			scm: scm{
+			Scm: Scm{
 				mainSCMDir: "",
 			},
 		}
@@ -708,7 +691,7 @@ func TestGitUpstream(t *testing.T) {
 		}
 
 		g := &Git{
-			scm: scm{
+			Scm: Scm{
 				command: GITCOMMAND,
 			},
 			Upstream: "origin/main",
@@ -934,7 +917,7 @@ func TestGitUntrackedMode(t *testing.T) {
 		}
 
 		g := &Git{
-			scm: scm{
+			Scm: Scm{
 				repoRootDir: "foo",
 			},
 		}
@@ -979,7 +962,7 @@ func TestGitIgnoreSubmodules(t *testing.T) {
 		}
 
 		g := &Git{
-			scm: scm{
+			Scm: Scm{
 				repoRootDir: "foo",
 			},
 		}
@@ -1111,7 +1094,7 @@ func TestGitCommit(t *testing.T) {
 		env.MockGitCommand("", tc.Output, "log", "-1", "--pretty=format:an:%an%nae:%ae%ncn:%cn%nce:%ce%nat:%at%nsu:%s%nha:%H%nrf:%D", "--decorate=full")
 
 		g := &Git{
-			scm: scm{
+			Scm: Scm{
 				command: GITCOMMAND,
 			},
 		}
@@ -1165,7 +1148,7 @@ func TestGitRemotes(t *testing.T) {
 		env.On("FileContent", "config").Return(tc.Config)
 
 		g := &Git{
-			scm: scm{
+			Scm: Scm{
 				repoRootDir: "foo",
 			},
 		}
@@ -1210,7 +1193,7 @@ func TestGitRepoName(t *testing.T) {
 		env.On("GOOS").Return(runtime.LINUX)
 
 		g := &Git{
-			scm: scm{
+			Scm: Scm{
 				repoRootDir: tc.RealDir,
 				mainSCMDir:  tc.WorkingDir,
 			},
